package com.school.project.controller;

import com.school.project.dto.DepartmentDTO;
import com.school.project.service.DepartmentService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Optional;

@RestController
public class DepartmentController {
    @Autowired(required=true)
    public DepartmentService departmentService;

    @PostMapping("/department")
    public void saveDepartment(@RequestBody DepartmentDTO departmentDTO){
        departmentService.saveDepartment(departmentDTO);
    }

    @GetMapping("/departments")
    public List<DepartmentDTO> readAllDepartments() {
        return departmentService.readDepartment();
    }

    @GetMapping("department/{id}")
    public ResponseEntity<DepartmentDTO> readDepartmentById(@PathVariable("id") Long id){
        DepartmentDTO departmentDTO=departmentService.readDepartmentById(id);

        if(departmentDTO == null){
            return ResponseEntity.status(HttpStatus.NOT_FOUND).build();
        }else {
            return ResponseEntity.of(Optional.of(departmentDTO));
        }
    }

    @GetMapping("departmentName/{name}")
    public DepartmentDTO findDepartmentByName(@PathVariable("name") String name){
        return departmentService.findDepartmentByName(name);
    }

    @PutMapping("department/{id}")
    public DepartmentDTO updateDepartmentById(@RequestBody DepartmentDTO departmentDTO,@PathVariable("id") Long id){
        return departmentService.updateDepartment(departmentDTO,id);
    }

    @DeleteMapping("department/{id}")
    public void deleteDepartmentById(@PathVariable("id") Long id){
        departmentService.deleteDepartmentById(id);
    }
}
